pub struct ActionStats {
pub initialized: bool,
pub bump: u8,
pub action_kind: u8,
pub owner: Pubkey,
pub total_created: u64,
pub update_count: u64,
pub total_executed: u64,
pub total_closed: u64,
pub last_created_at: i64,
pub last_updated_at: i64,
pub last_executed_at: i64,
pub last_closed_at: i64,
}Expand description
Account that tracks lifecycle statistics of actions known to the program.
Fields
initialized: boolWhether the account has been initialized.
bump: u8Bump seed used to derive the PDA for this account.
action_kind: u8The action kind.
owner: PubkeyThe owner.
total_created: u64Total number of actions that have ever been created.
update_count: u64Updated times.
total_executed: u64Total number of actions that have been executed.
total_closed: u64Total number of actions that have been closed.
last_created_at: i64Timestamp of the last created action.
last_updated_at: i64Timestamp of the last created action.
last_executed_at: i64Timestamp of the last executed action.
last_closed_at: i64Timestamp of the last closed action.